==> webservices-osgi-2.3-b55-sources.jar: com/sun/xml/ws/api/databinding/WSDLGenInfo.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.xml.ws.api.databinding;

import com.sun.xml.ws.api.server.Container;
import com.sun.xml.ws.api.wsdl.writer.WSDLGeneratorExtension;
import org.jvnet.ws.databinding.WSDLResolver;

/**
 * WSDLGenInfo provides the WSDL generation options
 *
 * @author shih-chang.chen@oracle.com
 */
public class WSDLGenInfo {
	WSDLResolver wsdlResolver;
	Container container;
    boolean inlineSchemas;
    WSDLGeneratorExtension[] extensions;
    
	public WSDLResolver getWsdlResolver() {
		return wsdlResolver;
	}
	public void setWsdlResolver(WSDLResolver wsdlResolver) {
		this.wsdlResolver = wsdlResolver;
	}
	public Container getContainer() {
		return container;
	}
	public void setContainer(Container container) {
		this.container = container;
	}
	public boolean isInlineSchemas() {
		return inlineSchemas;
	}
	public void setInlineSchemas(boolean inlineSchemas) {
		this.inlineSchemas = inlineSchemas;
	}
	public WSDLGeneratorExtension[] getExtensions() {
	    if (extensions == null) return new WSDLGeneratorExtension[0];
		return extensions;
	}
	public void setExtensions(WSDLGeneratorExtension[] extensions) {
		this.extensions = extensions;
	}
}

==> webservices-osgi-2.4.8-sources.jar: com/sun/xml/ws/api/databinding/WSDLGenInfo.java <==
/*
 * Copyright (c) 1997, 2019 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.api.databinding;

import com.oracle.webservices.api.databinding.WSDLResolver;
import com.sun.xml.ws.api.server.Container;
import com.sun.xml.ws.api.wsdl.writer.WSDLGeneratorExtension;

/**
 * WSDLGenInfo provides the WSDL generation options
 *
 * @author shih-chang.chen@oracle.com
 */
public class WSDLGenInfo {
	WSDLResolver wsdlResolver;
	Container container;
    boolean inlineSchemas;
    boolean secureXmlProcessingDisabled;
    WSDLGeneratorExtension[] extensions;

	public WSDLResolver getWsdlResolver() {
		return wsdlResolver;
	}
	public void setWsdlResolver(WSDLResolver wsdlResolver) {
		this.wsdlResolver = wsdlResolver;
	}
	public Container getContainer() {
		return container;
	}
	public void setContainer(Container container) {
		this.container = container;
	}
	public boolean isInlineSchemas() {
		return inlineSchemas;
	}
	public void setInlineSchemas(boolean inlineSchemas) {
		this.inlineSchemas = inlineSchemas;
	}
	public WSDLGeneratorExtension[] getExtensions() {
	    if (extensions == null) return new WSDLGeneratorExtension[0];
		return extensions;
	}
	public void setExtensions(WSDLGeneratorExtension[] extensions) {
		this.extensions = extensions;
	}

    public void setSecureXmlProcessingDisabled(boolean secureXmlProcessingDisabled) {
        this.secureXmlProcessingDisabled = secureXmlProcessingDisabled;
    }

    public boolean isSecureXmlProcessingDisabled() {
        return secureXmlProcessingDisabled;
    }
}
